import { ExtCLI } from "@hyext/cli";
export type BundleType = "RN_BUNDLE" | "MINI_GAME_RN" | string;
type GenerateUrlOption = {
    extType: string;
    extUuid: string;
    registerComponent: string;
    SDKVersion: string;
    md5: string;
    rnbaseurl?: string;
    rnbasemd5?: string;
    RNVersion?: string;
};
export declare function generateProdUrl({ extType, extUuid, registerComponent, SDKVersion, md5, rnbaseurl, rnbasemd5, RNVersion, }: GenerateUrlOption): string;
interface BuildInfo {
    extType: ExtCLI.RNExtType;
    bundleRelativePath: string;
    registerComponents: {
        name: string;
        queryString?: string;
    }[];
    platform: ExtCLI.RNPlatform;
    SDKVersion: string;
    publicPath: string;
    bundleType?: BundleType;
}
interface ProdBuildInfo extends BuildInfo {
    bundleMd5: string;
    baseUrl?: string;
    baseMd5?: string;
}
interface UniformBuildInfo extends BuildInfo {
    registerComponents: {
        name: string;
        queryString: string;
    }[];
}
export interface BaseOptions {
    builderName: string;
    extendPlatformConfig?: ExtendPlatformConfig;
}
interface ProdOptions extends BaseOptions {
    extInfo: {
        packageName: string;
        extUuid: string;
    };
    buildResultConfig: ProdBuildInfo[];
    onUrlCreateBefore?: onUrlCreateBefore;
    extendPlatformConfig?: ExtendPlatformConfig;
}
interface DevOptions extends BaseOptions {
    buildResultConfig: BuildInfo[];
}
interface UniformOptions extends BaseOptions {
    buildResultConfig: UniformBuildInfo[];
}
type onUrlCreateBefore = (opts: GenerateUrlOption, platform: string) => GenerateUrlOption;
/** 在生成 buildResult 的 platform 字段(ios/android) 前调用 */
type ExtendPlatformConfig = <T extends ExtCLI.RNBuildResultPlatformConfig>(rawConfig: T, platform: ExtCLI.RNPlatform, extType: string) => Promise<T>;
export declare function generateProdBuildResult({ builderName, extInfo, buildResultConfig, onUrlCreateBefore, extendPlatformConfig, }: ProdOptions): Promise<ExtCLI.RNBuildResult>;
export declare function generateProdBuildResultWithEncrypt({ builderName, extInfo, buildResultConfig, onUrlCreateBefore, outputBasePath }: ProdOptions & {
    outputBasePath: string;
}): Promise<ExtCLI.RNBuildResult>;
export declare function generateDevBuildResult({ builderName, buildResultConfig, }: DevOptions): Promise<ExtCLI.RNBuildResult>;
export declare function generateBuildResult({ builderName, buildResultConfig, extendPlatformConfig, }: UniformOptions): Promise<ExtCLI.RNBuildResult>;
export {};
